# Beamwalk

Helper program for launching laser light into optical fibers.

Originally created by Klaus Döringshoff.

## Installation

```
git clone https://github.com/bleykauf/beamwalk.git
cd beamwalk
pip install .
```

## Usage
To start: Open terminal and run
```
beamwalk
```
For command line options see
```
beamwalk --help
```
